==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'ÚJ DOKUMENTUM', # MODIF
	'bouton_ajouter_image' => 'ÚJ KÉP', # MODIF

	// D
	'double_clic_inserer_doc' => 'Dupla kattintással beszúrhatja a gyorshivatkozást a szövegbe.',

	// E
	'entree_dimensions' => 'Méret :',
	'entree_titre_document' => 'Dokumentum címe :',
	'entree_titre_image' => 'Kép címe :',

	// I
	'image_tourner_180' => '180° fordulás',
	'image_tourner_droite' => 'Fordulás 90° jobbra',
	'image_tourner_gauche' => 'Fordulás 90° balra',
	'info_document' => 'Dokumentum',
	'info_document_indisponible' => 'Ez a dokumentum nem érhető el.',
	'info_documents' => 'Dokumentumok',
	'info_inclusion_directe' => 'Közvetlen beszúrás :',
	'info_inclusion_vignette' => 'Bélyegkép beszúrása :',
	'info_installer_tous_documents' => 'Az összes dokumentum telepítése',
	'info_logo_max_taille' => 'Egy logo kisebb legyen, mint @maxi@ (ez a fájl pedig @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Felvenni egy dokumentumot a Neten :',
	'info_telecharger' => 'Feltöltés a gépéről :',

	// T
	'texte_documents_joints' => 'Engedelyézheti a dokumentumok hozzáadását (irodai fájlok, képek,
 multimédia, stb.) a cikkekhez és/vagy a rovatokhoz. Ezekre a fájlokra
 lehet majd hivatkozni a
 cikken belül, vagy külön megjeleníteni.', # MODIF
	'texte_documents_joints_2' => 'Ez a beállítás nem akadályozza a közvetlen képbeszűrást a cikkekbe.', # MODIF
	'titre_documents_joints' => 'Mellékelt dokumentumok',
	'tout_dossier_upload' => 'Az egész mappa @upload@',

	// U
	'upload_fichier_zip' => 'ZIP tipusú fájl',
	'upload_fichier_zip_texte' => 'ZIP tipusú az a fájl, amit akar telepíteni.',
	'upload_fichier_zip_texte2' => 'Ez a fájl lehet :',
	'upload_limit' => 'Ez a fájl túl nagy a szervernek; a máximalis <i>feltöltési</i> méret @max@.',
	'upload_zip_decompacter' => 'kitömöritve, és az összes eleme a honlapra telepítve. A honlapra telepített fájlok a következők lesznek :',
	'upload_zip_telquel' => 'Egymagában telepítve, mint ZIP tömörített állómány;'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'ÚJ DOKUMENTUM', # MODIF
	'bouton_ajouter_image' => 'ÚJ KÉP', # MODIF

	// D
	'double_clic_inserer_doc' => 'Dupla kattintással beszúrhatja a gyorshivatkozást a szövegbe.',

	// E
	'entree_dimensions' => 'Méret :',
	'entree_titre_document' => 'Dokumentum címe :',
	'entree_titre_image' => 'Kép címe :',

	// I
	'image_tourner_180' => '180° fordulás',
	'image_tourner_droite' => 'Fordulás 90° jobbra',
	'image_tourner_gauche' => 'Fordulás 90° balra',
	'info_document' => 'Dokumentum',
	'info_document_indisponible' => 'Ez a dokumentum nem érhető el.',
	'info_documents' => 'Dokumentumok',
	'info_inclusion_directe' => 'Közvetlen beszúrás :',
	'info_inclusion_vignette' => 'Bélyegkép beszúrása :',
	'info_installer_tous_documents' => 'Az összes dokumentum telepítése',
	'info_logo_max_taille' => 'Egy logo kisebb legyen, mint @maxi@ (ez a fájl pedig @actuel@).',
	'info_portfolio' => 'Portfolio',
	'info_referencer_doc_distant' => 'Felvenni egy dokumentumot a Neten :',
	'info_telecharger' => 'Feltöltés a gépéről :',

	// T
	'texte_documents_joints' => 'Engedelyézheti a dokumentumok hozzáadását (irodai fájlok, képek,
 multimédia, stb.) a cikkekhez és/vagy a rovatokhoz. Ezekre a fájlokra
 lehet majd hivatkozni a
 cikken belül, vagy külön megjeleníteni.', # MODIF
	'texte_documents_joints_2' => 'Ez a beállítás nem akadályozza a közvetlen képbeszűrást a cikkekbe.', # MODIF
	'titre_documents_joints' => 'Mellékelt dokumentumok',
	'tout_dossier_upload' => 'Az egész mappa @upload@',

	// U
	'upload_fichier_zip' => 'ZIP tipusú fájl',
	'upload_fichier_zip_texte' => 'ZIP tipusú az a fájl, amit akar telepíteni.',
	'upload_fichier_zip_texte2' => 'Ez a fájl lehet :',
	'upload_limit' => 'Ez a fájl túl nagy a szervernek; a máximalis <i>feltöltési</i> méret @max@.',
	'upload_zip_decompacter' => 'kitömöritve, és az összes eleme a honlapra telepítve. A honlapra telepített fájlok a következők lesznek :',
	'upload_zip_telquel' => 'Egymagában telepítve, mint ZIP tömörített állómány;',
];
